package com.xkrs.service.impl;

import com.xkrs.common.encapsulation.PromptMessageEnum;
import com.xkrs.common.tool.TokenUtil;
import com.xkrs.dao.NoticeDao;
import com.xkrs.dao.SysUserDao;
import com.xkrs.model.entity.NoticeEntity;
import com.xkrs.model.entity.SysUserEntity;
import com.xkrs.service.NoticeService;
import org.apache.hc.core5.util.TextUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Locale;
import java.util.Optional;

import static com.xkrs.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * 公告栏通知接口
 */
@Service
public class NoticeServiceImpl implements NoticeService {

    public static Logger log = LoggerFactory.getLogger(NoticeServiceImpl.class);

    private final Locale locale = LocaleContextHolder.getLocale();

    @Resource
    private NoticeDao noticeDao;

    @Resource
    private SysUserDao sysUserDao;

    /**
     * 更新通知
     */
    @Override
    public String updateNotice(String token, NoticeEntity updateQo) {
        if (TextUtils.isEmpty(token)) {
            return outputEncapsulationObject(PromptMessageEnum.PROCESS_FAIL, "参数错误", locale);
        }
        // 验证token
        String tokenUserName = TokenUtil.getTokenUserName(token);
        SysUserEntity sysUserEntity = sysUserDao.selectByUserName(tokenUserName);
        if (sysUserEntity == null) {
            return outputEncapsulationObject(PromptMessageEnum.USER_LOGIN_ERROR, "您还没有注册登录，请先注册登录", locale);
        }
        if (!sysUserEntity.getAccountType().equals("管理员")) {
            return outputEncapsulationObject(PromptMessageEnum.PROCESS_FAIL, "权限错误", locale);
        }
        Long id = updateQo.getId();
        String title = updateQo.getTitle();
        String content = updateQo.getContent();
        String author = updateQo.getAuthor();
        Integer state = updateQo.getState();
        if (id == null) {
            return outputEncapsulationObject(PromptMessageEnum.PROCESS_FAIL, "参数错误", locale);
        }
        Optional<NoticeEntity> targetOptional = noticeDao.findById(id);
        if (targetOptional.isEmpty()) {
            return outputEncapsulationObject(PromptMessageEnum.PROCESS_FAIL, "通知不存在", locale);
        }
        NoticeEntity target = targetOptional.get();
        if (!TextUtils.isEmpty(title)) {
            target.setTitle(title);
        }
        if (!TextUtils.isEmpty(content)) {
            target.setContent(content);
        }
        if (!TextUtils.isEmpty(author)) {
            target.setAuthor(author);
        }
        if (state != null) {
            target.setState(state);
        }
        noticeDao.save(target);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "更新成功", locale);
    }

    /**
     * 查询通知
     */
    @Override
    public String queryNotice() {
        List<NoticeEntity> noticeList = noticeDao.findAll(Sort.by(Sort.Direction.DESC, "id"));
        if (noticeList.size() > 0) {
            return outputEncapsulationObject(PromptMessageEnum.SUCCESS, noticeList.get(0), locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, null, locale);
    }

}
